import 'package:flutter/material.dart';

enum ScreenSize {
  unknown,
  xsmall,
  small,
  medium,
  large,
  xlarge,
}

class Responsive {
  static late double xlargeWidth = 1400;
  static late double largeWidth = 1200;
  static late double mediumWidth = 1024;
  static late double smallWidth = 380;
  // static late double xsmallWidth = 300;

  final BuildContext context;
  late final MediaQueryData mediaQueryData;
  final bool useScreenSize;

  Responsive._(this.context, {this.useScreenSize = true}) {
    mediaQueryData = MediaQuery.of(context);
  }

  factory Responsive.of(BuildContext context) {
    return Responsive._(context);
  }

  double get width => useScreenSize ? screenWidth : viewWidth;
  double get height => useScreenSize ? screenHeight : viewHeight;

  double get screenWidth => mediaQueryData.size.width;
  double get screenHeight => mediaQueryData.size.height;

  double get viewWidth => mediaQueryData.size.width - mediaQueryData.padding.left - mediaQueryData.padding.right;
  double get viewHeight => mediaQueryData.size.height - mediaQueryData.padding.top - mediaQueryData.padding.bottom;

  Orientation get orientation => mediaQueryData.orientation;
  bool get isPortrait => mediaQueryData.orientation == Orientation.portrait;
  bool get isLandscape => mediaQueryData.orientation == Orientation.landscape;

  bool isXL() => isExtraLargeScreen;
  bool get isExtraLargeScreen => width >= xlargeWidth;

  bool isL() => isLargeScreen;
  bool get isLargeScreen => width >= largeWidth && width < xlargeWidth;

  bool isM() => isMediumScreen;
  bool get isMediumScreen => width >= mediumWidth && width < largeWidth;

  bool isS() => isSmallScreen;
  bool get isSmallScreen => width >= smallWidth && width < mediumWidth;

  bool isXS() => isExtraSmallScreen;
  bool get isExtraSmallScreen => width < smallWidth;

  ScreenSize get screenSize => getScreenSize();
  ScreenSize getScreenSize() {
    if (isExtraSmallScreen) {
      return ScreenSize.xsmall;
    } else if (isSmallScreen) {
      return ScreenSize.small;
    } else if (isMediumScreen) {
      return ScreenSize.medium;
    } else if (isLargeScreen) {
      return ScreenSize.large;
    } else if (isExtraLargeScreen) {
      return ScreenSize.xlarge;
    } else {
      return ScreenSize.unknown;
    }
  }
}
